Flag Slurper
============

Flag slurper is a Red Team utility for :term:`Cyber Defense Competitions <CDC>`. It provides Auto PWN functionality,
as well as functionality for tracking obtained credentials, files, and most importantly, flags.

.. toctree::
   :maxdepth: 2

   projects
   files
   terms

.. toctree::
   :caption: Auto PWN

   autopwn/overview
   autopwn/post


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
